@@ -388,6 +388,7 @@ static gboolean dcop_client_attach_internal( DcopClient *client, gboolean anonym
 
             if ( f == NULL ) /* try .DCOPServer_hostname_display (for KDE > 2.0) */
             {
+                char *i;
                 char *display = getenv( "DISPLAY" );
 		gchar *display_real = g_strdup( display );
 		gchar *disppos;
@@ -396,6 +397,9 @@ static gboolean dcop_client_attach_internal( DcopClient *client, gboolean anonym
 		if ( ( disppos = strchr( display_real, '.' ) ) > strchr( display_real, ':' ) && disppos != NULL )
 		    (*disppos) = '\0';
 
+                while((i = strchr(display_real, ':')) != NULL)
+                   *i = '_';
+       
                 fname = (gchar *)g_realloc( fname, strlen( fname ) + 1 + 1 + strlen( display_real ) );
                 strcat( fname, "_" );
                 strcat( fname, display_real );
