@@ -1,7 +1,7 @@
 /*
  * KdeMenuSample.java
  *
- * Created on 8. Mrz 2002, 20:31
+ * Created on 8. Marz 2002, 20:31
  */
 
 //package com.werpu.sample3;
@@ -28,7 +28,7 @@ import org.kde.koala.KPushButton;
 /**
  * @author  Werner Punz werpu@gmx.at
  * To Java translated KDE Menu Example from
- * The kde.org KDE Tutorial from Antonio Larrosa Jimnez 
+ * The kde.org KDE Tutorial from Antonio Larrosa Jimenez 
  * http://person.wanadoo.es/antlarr/tutorial
  */
 public class KdeMenuSample extends KMainWindow {
@@ -70,7 +70,7 @@ public class KdeMenuSample extends KMainWindow {
         StringBuffer aboutText = new StringBuffer();
         
         aboutText.append("Menu Example: \n ");
-        aboutText.append("Originally written by Antonio Larrosa Jimnez larossa@kde.org \n");
+        aboutText.append("Originally written by Antonio Larrosa Jimenez larossa@kde.org \n");
         aboutText.append("Translated to Java by Werner Punz werpu@gmx.at \n");
         aboutText.append("Simple KDE Tutorial\n");
         aboutText.append("This tutorial comes with ABSOLUTELY NO WARRANTY\n");
@@ -86,7 +86,7 @@ public class KdeMenuSample extends KMainWindow {
      * creates the menu
      */
     private void createMenu() {
-       KMenuBar mainMenu = (KMenuBar) menuBar();
+       KMenuBar mainMenu = kmenuBar();
        mainMenu.insertItem("&File",createFileMenu());
        mainMenu.insertSeparator();
        mainMenu.insertItem("&About",createAboutMenu());
