@@ -15,15 +15,18 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  */
 #include "jsbindingplugin.h"
+#ifndef QT_ONLY
+#include "jsbindingplugin.moc"
+#endif // QT_ONLY
 
 namespace KJSEmbed {
 namespace Bindings {
 
-JSBindingPlugin::JSBindingPlugin(  QObject *parent, const char *name, const QStringList &args ): QObject(parent,name)
+JSBindingPlugin::JSBindingPlugin(  QObject *parent, const char *name, const QStringList &/*args*/ ): QObject(parent,name)
 {
 
 }
@@ -34,5 +37,3 @@ JSBindingPlugin::~JSBindingPlugin()
 }
 } // Bindings
 } // KJSEmbed
-
-#include "jsbindingplugin.moc"
