@@ -50,6 +50,7 @@
 extern "C" {
 extern VALUE set_obj_info(const char * className, smokeruby_object * o);
 extern VALUE qt_internal_module;
+extern VALUE qvariant_class;
 extern bool application_terminated;
 };
 
@@ -183,15 +184,15 @@ smokeruby_free(void * p)
 	unmapPointer(o, o->classId, 0);
 	object_count --;
 	
-	if (	strcmp(className, "QObject") == 0
-			|| strcmp(className, "QListBoxItem") == 0
-			|| strcmp(className, "QStyleSheetItem") == 0
-			|| strcmp(className, "KCommand") == 0
-			|| strcmp(className, "KNamedCommand") == 0
-			|| strcmp(className, "KMacroCommand") == 0
-			|| strcmp(className, "KAboutData") == 0
-			|| strcmp(className, "KCmdLineArgs") == 0
-			|| strcmp(className, "QSqlCursor") == 0 )
+	if (	qstrcmp(className, "QObject") == 0
+			|| qstrcmp(className, "QListBoxItem") == 0
+			|| qstrcmp(className, "QStyleSheetItem") == 0
+			|| qstrcmp(className, "KCommand") == 0
+			|| qstrcmp(className, "KNamedCommand") == 0
+			|| qstrcmp(className, "KMacroCommand") == 0
+			|| qstrcmp(className, "KAboutData") == 0
+			|| qstrcmp(className, "KCmdLineArgs") == 0
+			|| qstrcmp(className, "QSqlCursor") == 0 )
 	{
 		// Don't delete instances of these classes for now
 		free(o);
@@ -202,19 +203,19 @@ smokeruby_free(void * p)
 			free(o);
 			return;
 		}
-	} else if (strcmp(className, "QIconViewItem") == 0) {
+	} else if (qstrcmp(className, "QIconViewItem") == 0) {
 		QIconViewItem * item = (QIconViewItem *) o->ptr;
 		if (item->iconView() != 0) {
 			free(o);
 			return;
 		}
-	} else if (strcmp(className, "QCheckListItem") == 0) {
+	} else if (qstrcmp(className, "QCheckListItem") == 0) {
 		QCheckListItem * item = (QCheckListItem *) o->ptr;
 		if (item->parent() != 0 || item->listView() != 0) {
 			free(o);
 			return;
 		}
-	} else if (strcmp(className, "QListViewItem") == 0) {
+	} else if (qstrcmp(className, "QListViewItem") == 0) {
 		QListViewItem * item = (QListViewItem *) o->ptr;
 		if (item->parent() != 0 || item->listView() != 0) {
 			free(o);
@@ -226,7 +227,7 @@ smokeruby_free(void * p)
 			free(o);
 			return;
 		}
-	} else if (strcmp(className, "QPopupMenu") == 0) {
+	} else if (qstrcmp(className, "QPopupMenu") == 0) {
 		QPopupMenu * item = (QPopupMenu *) o->ptr;
 		if (item->parentWidget(false) != 0) {
 			free(o);
@@ -400,9 +401,7 @@ matches_arg(Smoke *smoke, Smoke::Index meth, Smoke::Index argidx, const char *ar
 {
     Smoke::Index *arg = smoke->argumentList + smoke->methods[meth].args + argidx;
     SmokeType type = SmokeType(smoke, *arg);
-    if(type.name() && !strcmp(type.name(), argtype))
-	return true;
-    return false;
+    return type.name() && qstrcmp(type.name(), argtype) == 0;
 }
 
 void *
@@ -422,6 +421,7 @@ construct_copy(smokeruby_object *o)
     Smoke::Index ccMeth = o->smoke->findMethod(o->classId, ccId);
 
     if(!ccMeth) {
+	delete[] ccArg;
 	return 0;
     }
 	Smoke::Index method = o->smoke->methodMaps[ccMeth].method;
@@ -747,17 +747,21 @@ static void marshall_unknown(Marshall *m) {
 
 static void marshall_charP(Marshall *m) {
     switch(m->action()) {
-      case Marshall::FromVALUE:
-	{
-	    VALUE rv = *(m->var());
-	    if(rv == Qnil) {
-                m->item().s_voidp = 0;
-                break;
-	    }
-		
-        m->item().s_voidp = strdup(StringValuePtr(rv));
-	}
-	break;
+    case Marshall::FromVALUE:
+    {
+        VALUE rv = *(m->var());
+	    if (rv == Qnil) {
+            m->item().s_voidp = 0;
+            break;
+        }
+	
+        int len = RSTRING(rv)->len;
+        char* mem = (char*) malloc(len+1);
+        memcpy(mem, StringValuePtr(rv), len);
+        mem[len] ='\0';
+        m->item().s_voidp = mem;
+    }
+        break;
       case Marshall::ToVALUE:
 	{
 	    char *p = (char*)m->item().s_voidp;
@@ -777,14 +781,18 @@ static void marshall_charP(Marshall *m) {
 
 void marshall_ucharP(Marshall *m) {
     switch(m->action()) {
-      case Marshall::FromVALUE:
-	{
-	    VALUE rv = *(m->var());
-	    if(rv == Qnil) {
-		m->item().s_voidp = 0;
-		break;
-	    }
-        m->item().s_voidp = strdup(StringValuePtr(rv));
+    case Marshall::FromVALUE:
+    {
+        VALUE rv = *(m->var());
+        if (rv == Qnil) {
+            m->item().s_voidp = 0;
+            break;
+        }
+        int len = RSTRING(rv)->len;
+        char* mem = (char*) malloc(len+1);
+        memcpy(mem, StringValuePtr(rv), len);
+        mem[len] ='\0';
+        m->item().s_voidp = mem;
 	}
 	break;
       case Marshall::ToVALUE:
@@ -801,9 +809,9 @@ static void
 init_codec() {
 	VALUE temp = rb_gv_get("$KCODE");
 	KCODE = StringValuePtr(temp);
-	if (strcmp(KCODE, "EUC") == 0) {
+	if (qstrcmp(KCODE, "EUC") == 0) {
 		codec = QTextCodec::codecForName("eucJP");
-	} else if (strcmp(KCODE, "SJIS") == 0) {
+	} else if (qstrcmp(KCODE, "SJIS") == 0) {
 		codec = QTextCodec::codecForName("Shift-JIS");
 	}
 }
@@ -815,13 +823,13 @@ qstringFromRString(VALUE rstring) {
 	}
 	
 	QString *	s;
-	if (strcmp(KCODE, "UTF8") == 0)
+	if (qstrcmp(KCODE, "UTF8") == 0)
 		s = new QString(QString::fromUtf8(StringValuePtr(rstring), RSTRING(rstring)->len));
-	else if (strcmp(KCODE, "EUC") == 0)
+	else if (qstrcmp(KCODE, "EUC") == 0)
 		s = new QString(codec->toUnicode(StringValuePtr(rstring)));
-	else if (strcmp(KCODE, "SJIS") == 0)
+	else if (qstrcmp(KCODE, "SJIS") == 0)
 		s = new QString(codec->toUnicode(StringValuePtr(rstring)));
-	else if(strcmp(KCODE, "NONE") == 0)
+	else if(qstrcmp(KCODE, "NONE") == 0)
 		s = new QString(QString::fromLatin1(StringValuePtr(rstring)));
 	else
 		s = new QString(QString::fromLocal8Bit(StringValuePtr(rstring), RSTRING(rstring)->len));
@@ -834,31 +842,31 @@ rstringFromQString(QString * s) {
 		init_codec();
 	}
 	
-	if (strcmp(KCODE, "UTF8") == 0)
+	if (qstrcmp(KCODE, "UTF8") == 0)
 		return rb_str_new2(s->utf8());
-	else if (strcmp(KCODE, "EUC") == 0)
+	else if (qstrcmp(KCODE, "EUC") == 0)
 		return rb_str_new2(codec->fromUnicode(*s));
-	else if (strcmp(KCODE, "SJIS") == 0)
+	else if (qstrcmp(KCODE, "SJIS") == 0)
 		return rb_str_new2(codec->fromUnicode(*s));
-	else if (strcmp(KCODE, "NONE") == 0)
+	else if (qstrcmp(KCODE, "NONE") == 0)
 		return rb_str_new2(s->latin1());
 	else
 		return rb_str_new2(s->local8Bit());
 }
 
 static void marshall_QString(Marshall *m) {
-    switch(m->action()) {
-      case Marshall::FromVALUE:
+	switch(m->action()) {
+	case Marshall::FromVALUE:
 	{
-	    QString* s = 0;
-	    if( *(m->var()) != Qnil) {
-               s = qstringFromRString(*(m->var()));
-            } else {
-                s = new QString(QString::null);
-            }
+		QString* s = 0;
+		if ( *(m->var()) != Qnil) {
+			s = qstringFromRString(*(m->var()));
+		} else {
+			s = new QString(QString::null);
+		}
 		
-	    m->item().s_voidp = s;
-	    m->next();
+		m->item().s_voidp = s;
+		m->next();
 		
 		if (!m->type().isConst() && *(m->var()) != Qnil && s != 0 && !s->isNull()) {
 			rb_str_resize(*(m->var()), 0);
@@ -866,29 +874,31 @@ static void marshall_QString(Marshall *m) {
 			rb_str_cat2(*(m->var()), StringValuePtr(temp));
 		}
 	    
-		if(s && m->type().isConst() && m->cleanup())
-		delete s;
+		if (s != 0 && m->cleanup()) {
+			delete s;
+		}
 	}
 	break;
-      case Marshall::ToVALUE:
+	case Marshall::ToVALUE:
 	{
-	    QString *s = (QString*)m->item().s_voidp;
-	    if(s) {
-	    	if (s->isNull()) {
-                    *(m->var()) = Qnil;
-	     	} else {
-               *(m->var()) = rstringFromQString(s);
-	     	}
-	     	if(m->cleanup() || m->type().isStack())
-	     	delete s;
-         } else {
-                *(m->var()) = Qnil;
-            }
+		QString *s = (QString*)m->item().s_voidp;
+		if (s != 0) {
+			if (s->isNull()) {
+				*(m->var()) = Qnil;
+			} else {
+				*(m->var()) = rstringFromQString(s);
+			}
+			if (m->cleanup() || m->type().isStack()) {
+				delete s;
+			}
+		} else {
+			*(m->var()) = Qnil;
+		}
 	}
 	break;
-      default:
-	m->unsupported();
-	break;
+	default:
+		m->unsupported();
+		break;
     }
 }
 
@@ -1564,8 +1574,16 @@ void marshall_QMapQStringQVariant(Marshall *m) {
 			VALUE value = rb_ary_entry(rb_ary_entry(temp, i), 1);
 			
 			smokeruby_object *o = value_obj_info(value);
-			if( !o || !o->ptr)
-                   continue;
+			if (!o || !o->ptr || o->classId != o->smoke->idClass("QVariant")) {
+				// If the value isn't a Qt::Variant, then try and construct
+				// a Qt::Variant from it
+				value = rb_funcall(qvariant_class, rb_intern("new"), 1, value);
+				if (value == Qnil) {
+					continue;
+				}
+				o = value_obj_info(value);
+			}
+
 			void * ptr = o->ptr;
 			ptr = o->smoke->cast(ptr, o->classId, o->smoke->idClass("QVariant"));
 			
@@ -1759,6 +1777,20 @@ void marshall_ValueItemList(Marshall *m) {
 		VALUE item = rb_ary_entry(list, i);
                 // TODO do type checking!
 		smokeruby_object *o = value_obj_info(item);
+
+		// Special case for the QValueList<QVariant> type
+		if (	qstrcmp(ItemSTR, "QVariant") == 0 
+				&& (!o || !o->ptr || o->classId != o->smoke->idClass("QVariant")) ) 
+		{
+			// If the value isn't a Qt::Variant, then try and construct
+			// a Qt::Variant from it
+			item = rb_funcall(qvariant_class, rb_intern("new"), 1, item);
+			if (item == Qnil) {
+				continue;
+			}
+			o = value_obj_info(item);
+		}
+
 		if(!o || !o->ptr)
                     continue;
 		void *ptr = o->ptr;
@@ -1836,8 +1868,8 @@ void marshall_ValueItemList(Marshall *m) {
     }
 }
 
-#define DEF_VALUELIST_MARSHALLER(ListIdent,ItemList,Item,Itr) namespace { char ListIdent##STR[] = #Item; };  \
-        Marshall::HandlerFn marshall_##ListIdent = marshall_ValueItemList<Item,ItemList,Itr,ListIdent##STR>;
+#define DEF_VALUELIST_MARSHALLER(ListIdent,ItemList,Item,Itr) namespace dummy { char ListIdent##STR[] = #Item; };  \
+        Marshall::HandlerFn marshall_##ListIdent = marshall_ValueItemList<Item,ItemList,Itr,dummy::ListIdent##STR>;
 
 DEF_VALUELIST_MARSHALLER( QVariantList, QValueList<QVariant>, QVariant, QValueList<QVariant>::Iterator )
 DEF_VALUELIST_MARSHALLER( QPixmapList, QValueList<QPixmap>, QPixmap, QValueList<QPixmap>::Iterator )
