@@ -1,10 +1,10 @@
-// Qt-CSharp tutorial 3
+// Qt# tutorial 3
 // Based on the Qt tutorial
 // Implemented by Marcus Urban
 
 using System;
 using Qt;
-using QtSupport;
+
 
 public class Example {
 
