@@ -1,9 +1,9 @@
 #include "kbrowsersignals.h"
-#include "kparthost.h"
+#include "xparthost_kpart.h"
 #include "xbrowserextension_stub.h"
 #include <kurl.h>
 
-KBrowserSignals::KBrowserSignals( KPartHost *_part, DCOPRef extension )
+KBrowserSignals::KBrowserSignals( XPartHost_KPart *_part, DCOPRef extension )
     : KParts::BrowserExtension( _part )
 {
     qDebug("KBrowserSignals constructor");
